==> SD_v1.4.1.zip: README.md <==
# Sermon Distributor (1.4.1)

 ![Sermon Distributor image](https://raw.githubusercontent.com/SermonDistributor/Joomla-3-Component/master/admin/assets/images/component-300.jpg "The Sermon Distributor")

Distributor is a highly advanced sermon distributor that runs on the [Joomla 3.x](http://www.joomla.org) framework. You can link a shared folder from Dropbox to the component and use Dropbox as your file host, not to mention the advanced auto builder that gives you the ability to simply load sermons to your website by only adding them to Dropbox.

The best way to see all your options is to install this component on you Joomla website and test all features yourself. Here is a [direct download link](https://github.com/SermonDistributor/Joomla-3-Component/archive/master.zip)

 **If you like our component please rate it on the [Joomla Index](http://extensions.joomla.org/extensions/extension/living/religion/sermon-distributor)**

### Example Website, That Has Over 6000 Audio Files

[LoudVoice.org](http://www.loudvoice.org)

### Some Video Demonstrations

+ [Setup overview](https://youtu.be/yMPp1Cp3W_0?t=20m8s)
+ [Setup Dropbox](https://youtu.be/btpKFDk0-dI)

# Build Details

+ *Company*: [Vast Development Method](https://www.vdm.io/)
+ *Author*: [Llewellyn van der Merwe](mailto:joomla@vdm.io)
+ *Name*: [Sermon Distributor](https://www.vdm.io/)
+ *First Build*: 22nd October, 2015
+ *Last Build*: 17th February, 2017
+ *Version*: 1.4.1
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html

## Build Time :hourglass:

**181 Hours** or **23 Eight Hour Days** (actual time the author saved -
due to [Automated Component Builder](https://www.vdm.io/joomla-component-builder))

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> never making one mistake or taking any coffee break.)

+ *Line count*: **64745**
+ *File count*: **439**
+ *Folder count*: **90**

**119 Hours** or **15 Eight Hour Days** (the actual time the author spent)

> (with the following break down:
> **debugging @45hours** = codingtime / 4;
> **planning @26hours** = codingtime / 7;
> **mapping @18hours** = codingtime / 10;
> **office @30hours** = codingtime / 6;)

**300 Hours** or **38 Eight Hour Days**
(a total of the realistic time frame for this project)

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> with the normal everyday realities at the office, that includes the component planning, mapping & debugging.)

Project duration: **7.6 weeks** or **1.6 months**

> This **component** was build with a Joomla [Automated Component Builder](https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe](mailto:joomla@vdm.io)

## Donations

 If you want to support this project, please consider donating:
 * PayPal: pay@vdm.io
 * Bitcoin: 3H35PYwikEosvcjxHXGPLS1GufZ4b4iFu3

==> SD_v2.0.0.zip: README.md <==
# Sermon Distributor (2.0.x)

 ![Sermon Distributor image](https://raw.githubusercontent.com/SermonDistributor/Joomla-3-Component/master/admin/assets/images/vdm-component.jpg "The Sermon Distributor")

Distributor is a highly advanced sermon distributor that runs on the [Joomla 3.x](http://www.joomla.org) framework. You can link a shared folder from Dropbox to the component and use Dropbox as your file host, not to mention the advanced auto builder that gives you the ability to simply load sermons to your website by only adding them to Dropbox.

The best way to see all your options is to install this component on you Joomla website and test all features yourself. Here is a [direct download link](https://github.com/SermonDistributor/Joomla-3-Component/archive/master.zip)

 **If you like our component please rate it on the [Joomla Index](http://extensions.joomla.org/extensions/extension/living/religion/sermon-distributor)**

### Example Website, That Has Over 6000 Audio Files

[LoudVoice.org](http://www.loudvoice.org)

### Some Video Demonstrations

+ [Setup overview](https://youtu.be/yMPp1Cp3W_0?t=20m8s)
+ [Setup Dropbox](https://youtu.be/btpKFDk0-dI)

# Build Details

+ *Company*: [Vast Development Method](https://www.vdm.io/)
+ *Author*: [Llewellyn van der Merwe](mailto:joomla@vdm.io)
+ *Name*: [Sermon Distributor](https://www.vdm.io/)
+ *First Build*: 22nd October, 2015
+ *Last Build*: 3rd March, 2018
+ *Version*: 2.0.x
+ *Copyright*: Copyright (C) 2015. All Rights Reserved
+ *License*: GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html

## Build Time :hourglass:

**180 Hours** or **23 Eight Hour Days** (actual time the author saved -
due to [Automated Component Builder](https://www.vdm.io/joomla-component-builder))

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> never making one mistake or taking any coffee break.)

+ *Line count*: **64404**
+ *File count*: **451**
+ *Folder count*: **93**

**118 Hours** or **14 Eight Hour Days** (the actual time the author spent)

> (with the following break down:
> **debugging @45hours** = codingtime / 4;
> **planning @26hours** = codingtime / 7;
> **mapping @18hours** = codingtime / 10;
> **office @30hours** = codingtime / 6;)

**298 Hours** or **37 Eight Hour Days**
(a total of the realistic time frame for this project)

> (if creating a folder and file took **5 seconds** and writing one line of code took **10 seconds**,
> with the normal everyday realities at the office, that includes the component planning, mapping & debugging.)

Project duration: **7.4 weeks** or **1.5 months**

> This **component** was build with a Joomla [Automated Component Builder](https://www.vdm.io/joomla-component-builder).
> Developed by [Llewellyn van der Merwe](mailto:joomla@vdm.io)

## Donations

Come on buy me a coffee :)
 * PayPal: [paypal.me/payvdm](https://www.paypal.me/payvdm)
 * Bitcoin: 18vURxYpPFjvNk8BnUy1ovCAyQmY3MzkSf
 * Ethereum: 0x9548144662b47327c954f3e214edb96662d51218
